==> order-center-infrastructure-2.0.9-CLOUD-TEST-20220428.223113-121-sources.jar: com/tydic/dyc/oc/repository/po/UocCmpOrderPo.java <==
package com.tydic.dyc.oc.repository.po;

import com.tydic.utils.generatedoc.annotation.DocField;
import lombok.Data;

import java.io.Serializable;
import java.util.Date;

/**
 * 标题:UocCmpOrderPo
 * 说明:比选单
 * 时间:2022-02-23 20:57
 * 作者:罗有
 **/
@Data
public class UocCmpOrderPo implements Serializable {
	private static final long serialVersionUID =  1643959255502011330L;

	@DocField(value = "比选单id")
	private Long cmpOrderId;

	@DocField(value = "订单id")
	private Long orderId;

	@DocField(value = "比选单号")
	private String cmpOrderNo;

	@DocField(value = "订单状态")
	private String cmpOrderState;

	@DocField(value = "比选单来源")
	private Integer cmpOrderSource;

	@DocField(value = "租户ID")
	private String tenantId;

	@DocField(value = "创建时间")
	private Date createTime;

	@DocField(value = "创建时间 开始")
	private Date createTimeStart;

	@DocField(value = "创建时间 结束")
	private Date createTimeEnd;

	@DocField(value = "创建工号")
	private String createOperId;

	@DocField(value = "创建人名称")
	private String createOperName;

	@DocField(value = "机构id")
	private String createOrgId;

	@DocField(value = "机构名称")
	private String createOrgName;

	@DocField(value = "更新时间")
	private Date updateTime;

	@DocField(value = "更新时间 开始")
	private Date updateTimeStart;

	@DocField(value = "更新时间 结束")
	private Date updateTimeEnd;

	@DocField(value = "更新工号")
	private String updateOperId;

	@DocField(value = "扩展字段1")
	private String extField1;

	@DocField(value = "扩展字段2")
	private String extField2;

	@DocField(value = "扩展字段3")
	private String extField3;

	@DocField(value = "扩展字段4")
	private String extField4;

	@DocField(value = "扩展字段5")
	private String extField5;

	@DocField(value = "备注")
	private String remark;

	@DocField(value = "删除标志1已删除")
	private Integer delTag;

	@DocField(value = "排序")
	private String orderBy;

}

==> order-center-infrastructure-3.1.0-CLOUD-TEST-20230918.052400-110-sources.jar: com/tydic/dyc/oc/repository/po/UocCmpOrderPo.java <==
package com.tydic.dyc.oc.repository.po;


import lombok.Data;
import lombok.EqualsAndHashCode;

import java.io.Serializable;
import java.util.Date;

/**
 * 标题:UocCmpOrderPo
 * 说明:比选单
 * 时间:2022-02-23 20:57
 * 作者:罗有
 **/
@Data
@EqualsAndHashCode(callSuper=false)
public class UocCmpOrderPo implements Serializable {
	private static final long serialVersionUID =  1643959255502011330L;

	//比选单id")
	private Long cmpOrderId;

	//订单id")
	private Long orderId;

	//比选单号")
	private String cmpOrderNo;

	//订单状态")
	private String cmpOrderState;

	//比选单来源")
	private Integer cmpOrderSource;

	//租户ID")
	private String tenantId;

	//创建时间")
	private Date createTime;

	//创建时间 开始")
	private Date createTimeStart;

	//创建时间 结束")
	private Date createTimeEnd;

	//创建工号")
	private String createOperId;

	//创建人名称")
	private String createOperName;

	//机构id")
	private String createOrgId;

	//机构名称")
	private String createOrgName;

	//更新时间")
	private Date updateTime;

	//更新时间 开始")
	private Date updateTimeStart;

	//更新时间 结束")
	private Date updateTimeEnd;

	//更新工号")
	private String updateOperId;

	//扩展字段1")
	private String extField1;

	//扩展字段2")
	private String extField2;

	//扩展字段3")
	private String extField3;

	//扩展字段4")
	private String extField4;

	//扩展字段5")
	private String extField5;

	//备注")
	private String remark;

	//删除标志1已删除")
	private Integer delTag;

	//排序")
	private String orderBy;
    
    /**
     * 比选单快照
     */
    //比选单快照")
    private String cmpSnapshot;

	 //@DocField(value = "归档表后缀")
	private String dataAchiveTabSuffix;

}
